@@ -1,5 +1,6 @@
 import bolinette.commands.run_server
 import bolinette.commands.init_db
 import bolinette.commands.init_docs
-import bolinette.commands.create_user
+import bolinette.commands.user_management
+import bolinette.commands.create_files
 import bolinette.commands.hello
