@@ -1,17 +1,17 @@
-from typing import Type, TypeVar, Generic
+from typing import TypeVar, Generic
 
 _T = TypeVar('_T')
 
 
 class InitProxy(Generic[_T]):
-    def __init__(self, proxy_cls: Type[_T], **kwargs):
+    def __init__(self, proxy_cls: type[_T], **kwargs):
         self._proxy_cls = proxy_cls
         self._kwargs = kwargs
 
     def instantiate(self, **kwargs) -> _T:
         return self._proxy_cls(**(self._kwargs | kwargs))
 
-    def of_type(self, proxy_cls: Type[_T]) -> bool:
+    def of_type(self, proxy_cls: type[_T]) -> bool:
         return self._proxy_cls == proxy_cls
 
     def __repr__(self):
